==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ru.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управление Параметры Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управление Галерея");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Полноразмерные Ширина изображения");
define('MANAGE_GALLERY_FULL_HEIGHT', "Увеличить Высота");
define('MANAGE_GALLERY_THUMB_WIDTH', "Эскиз Ширина изображения");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Эскиз Высота изображения");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Заповедник Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показать Названия");
define('MANAGE_GALLERY_DISABLE_SORT', "Отключить Сортировать");
define('MANAGE_GALLERY_DELETE_IMAGE', "Удалить изображение");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Сохранить сортировку");
define('MANAGE_GALLERY_PUBLISH_MSG', "Нажмите кнопку &quot;Обновить&quot;, чтобы опубликовать <br /> ваши загруженные изображения.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Все изображения были изменены и настройки были сохранены.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Был ошибка изменения размера изображения или сохранения настроек.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш образ (ы) был загружен.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Был Ошибка при загрузке изображения (ы).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, который вы пытаетесь загрузить, не является изображением.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, который вы пытаетесь загрузить слишком большой.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Название было сохранено.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Вы уверены, что хотите удалить изображение");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Изображение было удалено.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Был ошибка удаления изображения.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Сохранение параметров и изменение размеров изображений, пожалуйста, подождите ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Загрузка, подождите пожалуйста ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Порядок сортировки не был сохранен. Вы хотите, чтобы сохранить порядок сортировки?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Порядок сортировки изображений сохранен.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Был ошибка при сохранении рода изображения.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ru.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управление Параметры Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управление Галерея");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Полноразмерные Ширина изображения");
define('MANAGE_GALLERY_FULL_HEIGHT', "Увеличить Высота");
define('MANAGE_GALLERY_THUMB_WIDTH', "Эскиз Ширина изображения");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Эскиз Высота изображения");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Заповедник Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показать Названия");
define('MANAGE_GALLERY_DISABLE_SORT', "Отключить Сортировать");
define('MANAGE_GALLERY_DELETE_IMAGE', "Удалить изображение");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Сохранить сортировку");
define('MANAGE_GALLERY_PUBLISH_MSG', "Нажмите кнопку &quot;Обновить&quot;, чтобы опубликовать <br /> ваши загруженные изображения.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Все изображения были изменены и настройки были сохранены.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Был ошибка изменения размера изображения или сохранения настроек.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш образ (ы) был загружен.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Был Ошибка при загрузке изображения (ы).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, который вы пытаетесь загрузить, не является изображением.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, который вы пытаетесь загрузить слишком большой.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Название было сохранено.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Вы уверены, что хотите удалить изображение");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Изображение было удалено.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Был ошибка удаления изображения.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Сохранение параметров и изменение размеров изображений, пожалуйста, подождите ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Загрузка, подождите пожалуйста ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Порядок сортировки не был сохранен. Вы хотите, чтобы сохранить порядок сортировки?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Порядок сортировки изображений сохранен.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Был ошибка при сохранении рода изображения.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Файл, который вы пытаетесь загрузить, больше, чем настройки PHP «upload_max_filesize» или «post_max_size». Обратитесь к системному администратору, чтобы увеличить эти ограничения.");
?>
